@@ -3,8 +3,8 @@
 #' Filter a dataframe by some boolean condition of one numeric variable
 #' and returns the result along with tidyverse code used to generate it.
 #'
-#' @param .data a dataframe to filter
-#' @param var character of the column in \code{.data} to filter by
+#' @param .data a dataframe or survey design object to filter
+#' @param var character of the column in `.data` to filter by
 #' @param op  a logical operator of "<=", "<", ">=", ">", "==" or "!="
 #'        for the boolean condition
 #' @param num a number for which the \code{op} applies to
@@ -15,18 +15,32 @@
 #' cat(code(filtered))
 #' head(filtered)
 #'
-#' @author Owen Jin
+#' require(survey)
+#' data(api)
+#' svy <- svydesign(~dnum+snum, weights = ~pw, fpc = ~fpc1+fpc2, data = apiclus2)
+#' (svy_filtered <- filterNumeric(svy, var = "api00", op = "<", num = 700))
+#' cat(code(svy_filtered))
+#'
+#' @author Owen Jin, Tom Elliott
 #' @export
+#' @md
 filterNumeric <- function(.data, var, op, num) {
     mc <- match.call()
     dataname <- mc$.data
 
-    exp <- ~.DATA %>% dplyr::filter(.VARNAME.OP.NUM)
+    is_survey <- is_survey(.data)
+    if (is_survey && !inherits(.data, "tbl_svy")) {
+        .data <- srvyr::as_survey(.data)
+        dataname <- glue::glue("{dataname} %>% srvyr::as_survey()")
+    }
+
+    exp <- ~.DATA %>% .FUN(.VARNAME.OP.NUM)
     exp <- replaceVars(exp,
         .VARNAME = var,
         .OP = op,
         .NUM = num,
-        .DATA = dataname
+        .DATA = dataname,
+        .FUN = if (is_survey) "srvyr::filter" else "dplyr::filter"
     )
     interpolate(exp)
 }
